==> hoteldruid-mod-ca_2.1.1-1.tar.gz: ca/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "El <b>nom</b> de l'usuari"; break;
case "verrà cambiato da":  			$messaggio = "serà canviat de"; break;
case "a":  					$messaggio = "a"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "El <b>login</b> de l'usuari"; break;
case "password conservata in chiaro":  		$messaggio = "contrasenya desada en text clar"; break;
case "password conservata criptata con md5":  	$messaggio = "contrasenya desada encriptada amb md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "contrasenya desada encriptada amb mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "contrasenya desada encriptada amb mhash"; break;
case "disabilitato":  				$messaggio = "deshabilitat"; break;
case "Inserisci una nuova password":  		$messaggio = "Insereix una contrasenya nova"; break;
case "Ripeti la password":  			$messaggio = "Repeteix la contrasenya"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Ja existeix</div> un usuari anomenat"; break;
case "Nuova password dell'utente":  		$messaggio = "Nova contrasenya de l'usuari"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">no</div> inserida correctament"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>No</b> s'ha dut a terme cap canvi"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Ja existeix un usuari anomenat"; break;
case "Le nuove password non coincidono":  	$messaggio = "Les contrasenyes noves no coincideixen"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Insereix una contrasenya nova per l'usuari"; break;
case "Nuova password":  			$messaggio = "Contgrasenya nova"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "Gestió d'usuaris d'HotelDruid"; break;
case "N°":  					$messaggio = "N°"; break;
case "nome":  					$messaggio = "nom"; break;
case "modifica":  				$messaggio = "modifica"; break;
case "password criptata con md5":  		$messaggio = "contrasenya encriptada amb md5"; break;
case "password criptata con mcrypt":  		$messaggio = "contrasenya encriptada amb mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "contrasenya encriptada amb mhash"; break;
case "password":  				$messaggio = "contrasenya"; break;
case "privilegi":  				$messaggio = "privilegis"; break;
case "Amministratore":  			$messaggio = "Administrador"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Habilitar per utilitzar d'altres usuaris"; break;
case "Modifica gli utenti":  			$messaggio = "Modifica els usuaris"; break;
case "Aggiungi":  				$messaggio = "Afegir"; break;
case "un nuovo utente chiamato":  		$messaggio = "un usuari nou anomenat"; break;
case "Importa i privilegi":  			$messaggio = "Importar els privilegis"; break;
case "dell'utente":  				$messaggio = "de l'usuari"; break;
case "del gruppo":  				$messaggio = "del grup"; break;
case "dall'utente":  				$messaggio = "des de l'usuari"; break;
case "Privilegi importati":  			$messaggio = "Privilegis importats"; break;
case "Importa":  				$messaggio = "Importar"; break;
case "gruppi":  				$messaggio = "grups"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Grups de l'usuari actualitzats"; break;
case "Gruppi dell'utente":  			$messaggio = "Grups de l'usuari"; break;
case "Nuovo gruppo":  				$messaggio = "Grup nou"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Ja existeix un grup anomenat"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "cancella":  				$messaggio = "esborrar"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Segur que cal <b style=\"font-weight: normal; color: red;\">esborrar</b> l'usuari"; break;
case "SI":  					$messaggio = "SÍ"; break;
case "NO":  					$messaggio = "NO"; break;
case "login":  					$messaggio = "login"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ca_2.1.3-1.tar.gz: ca/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "El <b>nom</b> de l'usuari"; break;
case "verrà cambiato da":  			$messaggio = "serà canviat de"; break;
case "a":  					$messaggio = "a"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "El <b>login</b> de l'usuari"; break;
case "password conservata in chiaro":  		$messaggio = "contrasenya desada en text clar"; break;
case "password conservata criptata con md5":  	$messaggio = "contrasenya desada encriptada amb md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "contrasenya desada encriptada amb mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "contrasenya desada encriptada amb mhash"; break;
case "disabilitato":  				$messaggio = "deshabilitat"; break;
case "Inserisci una nuova password":  		$messaggio = "Insereix una contrasenya nova"; break;
case "Ripeti la password":  			$messaggio = "Repeteix la contrasenya"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Ja existeix</div> un usuari anomenat"; break;
case "Nuova password dell'utente":  		$messaggio = "Nova contrasenya de l'usuari"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">no</div> inserida correctament"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>No</b> s'ha dut a terme cap canvi"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Ja existeix un usuari anomenat"; break;
case "Le nuove password non coincidono":  	$messaggio = "Les contrasenyes noves no coincideixen"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Insereix una contrasenya nova per l'usuari"; break;
case "Nuova password":  			$messaggio = "Contgrasenya nova"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "Gestió d'usuaris d'HotelDruid"; break;
case "N°":  					$messaggio = "N°"; break;
case "nome":  					$messaggio = "nom"; break;
case "modifica":  				$messaggio = "modifica"; break;
case "password criptata con md5":  		$messaggio = "contrasenya encriptada amb md5"; break;
case "password criptata con mcrypt":  		$messaggio = "contrasenya encriptada amb mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "contrasenya encriptada amb mhash"; break;
case "password":  				$messaggio = "contrasenya"; break;
case "privilegi":  				$messaggio = "privilegis"; break;
case "Amministratore":  			$messaggio = "Administrador"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Habilitar per utilitzar d'altres usuaris"; break;
case "Modifica gli utenti":  			$messaggio = "Modifica els usuaris"; break;
case "Aggiungi":  				$messaggio = "Afegir"; break;
case "un nuovo utente chiamato":  		$messaggio = "un usuari nou anomenat"; break;
case "dell'utente":  				$messaggio = "de l'usuari"; break;
case "del gruppo":  				$messaggio = "del grup"; break;
case "dall'utente":  				$messaggio = "des de l'usuari"; break;
case "Privilegi importati":  			$messaggio = "Privilegis importats"; break;
case "Importa":  				$messaggio = "Importar"; break;
case "gruppi":  				$messaggio = "grups"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Grups de l'usuari actualitzats"; break;
case "Gruppi dell'utente":  			$messaggio = "Grups de l'usuari"; break;
case "Nuovo gruppo":  				$messaggio = "Grup nou"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Ja existeix un grup anomenat"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "cancella":  				$messaggio = "esborrar"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Segur que cal <b style=\"font-weight: normal; color: red;\">esborrar</b> l'usuari"; break;
case "SI":  					$messaggio = "SÍ"; break;
case "NO":  					$messaggio = "NO"; break;
case "login":  					$messaggio = "login"; break;
case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
case "solo i privilegi":  			$messaggio = "only privileges"; break;
case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
